Author: kevlo
Date: Thu Dec 15 06:29:13 2011
New Revision: 228526
URL: http://svn.freebsd.org/changeset/base/228526

Log:
  s/timout/timeout

Modified:
  head/sys/dev/bxe/bxe_reg.h
  head/sys/dev/esp/ncr53c9x.c
  head/sys/dev/twa/tw_osl.h
  head/sys/xen/xenstore/xenstore.c

Modified: head/sys/dev/bxe/bxe_reg.h
==============================================================================
--- head/sys/dev/bxe/bxe_reg.h  Thu Dec 15 06:25:19 2011        (r228525)
+++ head/sys/dev/bxe/bxe_reg.h  Thu Dec 15 06:29:13 2011        (r228526)
@@ -1594,7 +1594,7 @@
 /*
  * [RW 1] Setting this bit enables a timer in the GRC block to timeout an
  * access that does not finish within
- * ~misc_registers_grc_timout_val.grc_timeout_val cycles. When this bit is
+ * ~misc_registers_grc_timeout_val.grc_timeout_val cycles. When this bit is
  * cleared; this timeout is disabled. If this timeout occurs; the GRC shall
  * assert it attention output.
  */

Modified: head/sys/dev/esp/ncr53c9x.c
==============================================================================
--- head/sys/dev/esp/ncr53c9x.c Thu Dec 15 06:25:19 2011        (r228525)
+++ head/sys/dev/esp/ncr53c9x.c Thu Dec 15 06:29:13 2011        (r228526)
@@ -316,7 +316,7 @@ ncr53c9x_attach(struct ncr53c9x_softc *s
         * The recommended timeout is 250ms.  This register is loaded
         * with a value calculated as follows, from the docs:
         *
-        *              (timout period) x (CLK frequency)
+        *              (timeout period) x (CLK frequency)
         *      reg = -------------------------------------
         *               8192 x (Clock Conversion Factor)
         *

Modified: head/sys/dev/twa/tw_osl.h
==============================================================================
--- head/sys/dev/twa/tw_osl.h   Thu Dec 15 06:25:19 2011        (r228525)
+++ head/sys/dev/twa/tw_osl.h   Thu Dec 15 06:29:13 2011        (r228526)
@@ -153,7 +153,7 @@ struct twa_softc {
        struct mtx              sim_lock_handle;/* sim lock shared with cam */
        struct mtx              *sim_lock;/* ptr to sim lock */
 
-       struct callout          watchdog_callout[2]; /* For command timout */
+       struct callout          watchdog_callout[2]; /* For command timeout */
        TW_UINT32               watchdog_index;
 
 #ifdef TW_OSL_DEBUG

Modified: head/sys/xen/xenstore/xenstore.c
==============================================================================
--- head/sys/xen/xenstore/xenstore.c    Thu Dec 15 06:25:19 2011        
(r228525)
+++ head/sys/xen/xenstore/xenstore.c    Thu Dec 15 06:29:13 2011        
(r228526)
@@ -559,7 +559,7 @@ xs_read_store(void *tdata, unsigned len)
                         * when msleep returns.
                         */
                        error = msleep(xen_store, &xs.ring_lock, PCATCH|PDROP,
-                           "xbread", /*timout*/0);
+                           "xbread", /*timeout*/0);
                        if (error && error != EWOULDBLOCK)
                                return (error);
                        continue;
_______________________________________________
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

Reply via email to